@@ -3,12 +3,12 @@
 import sys
 import warnings
 
+import pytest
 import numpy as np
 
 from .test_table import comparerecords
 from ..hdu.base import _ValidHDU
 from ....io import fits
-from ....tests.helper import pytest
 
 from . import FitsTestCase
 
@@ -17,7 +17,7 @@ class TestChecksumFunctions(FitsTestCase):
 
     # All checksums have been verified against CFITSIO
     def setup(self):
-        super(TestChecksumFunctions, self).setup()
+        super().setup()
         self._oldfilters = warnings.filters[:]
         warnings.filterwarnings(
             'error',
@@ -32,7 +32,7 @@ class TestChecksumFunctions(FitsTestCase):
         _ValidHDU._get_timestamp = lambda self: '2013-12-20T13:36:10'
 
     def teardown(self):
-        super(TestChecksumFunctions, self).teardown()
+        super().teardown()
         warnings.filters = self._oldfilters
         _ValidHDU._get_timestamp = self._old_get_timestamp
 
@@ -43,7 +43,7 @@ class TestChecksumFunctions(FitsTestCase):
     def test_image_create(self):
         n = np.arange(100, dtype=np.int64)
         hdu = fits.PrimaryHDU(n)
-        hdu.writeto(self.temp('tmp.fits'), clobber=True, checksum=True)
+        hdu.writeto(self.temp('tmp.fits'), overwrite=True, checksum=True)
         with fits.open(self.temp('tmp.fits'), checksum=True) as hdul:
             assert (hdu.data == hdul[0].data).all()
             assert 'CHECKSUM' in hdul[0].header
@@ -55,26 +55,11 @@ class TestChecksumFunctions(FitsTestCase):
                 assert hdul[0].header['CHECKSUM'] == 'ZHMkeGKjZGKjbGKj'
                 assert hdul[0].header['DATASUM'] == '4950'
 
-    def test_nonstandard_checksum(self):
-        hdu = fits.PrimaryHDU(np.arange(10.0 ** 6, dtype=np.float64))
-        hdu.writeto(self.temp('tmp.fits'), clobber=True,
-                    checksum='nonstandard')
-        del hdu
-        with fits.open(self.temp('tmp.fits'), checksum='nonstandard') as hdul:
-            assert 'CHECKSUM' in hdul[0].header
-            assert 'DATASUM' in hdul[0].header
-
-            if not sys.platform.startswith('win32'):
-                # The checksum ends up being different on Windows, possibly due
-                # to slight floating point differences
-                assert hdul[0].header['CHECKSUM'] == 'jD4Am942jC48j948'
-                assert hdul[0].header['DATASUM'] == '4164005614'
-
     def test_scaled_data(self):
         with fits.open(self.data('scale.fits')) as hdul:
             orig_data = hdul[0].data.copy()
             hdul[0].scale('int16', 'old')
-            hdul.writeto(self.temp('tmp.fits'), clobber=True, checksum=True)
+            hdul.writeto(self.temp('tmp.fits'), overwrite=True, checksum=True)
             with fits.open(self.temp('tmp.fits'), checksum=True) as hdul1:
                 assert (hdul1[0].data == orig_data).all()
                 assert 'CHECKSUM' in hdul1[0].header
@@ -98,7 +83,7 @@ class TestChecksumFunctions(FitsTestCase):
 
         # Reopen the new file and save it back again with a checksum
         with fits.open(self.temp('rescaled.fits')) as hdul:
-            hdul.writeto(self.temp('rescaled2.fits'), clobber=True,
+            hdul.writeto(self.temp('rescaled2.fits'), overwrite=True,
                          checksum=True)
 
         # Now do like in the first writeto but use checksum immediately
@@ -130,7 +115,7 @@ class TestChecksumFunctions(FitsTestCase):
             ('8aCN8X9N8aAN8W9N', '1756785133'), ('UhqdUZnbUfnbUZnb', '0'),
             ('4cQJ5aN94aNG4aN9', '0')]
         with fits.open(self.data('o4sp040b0_raw.fits'), uint=True) as hdul:
-            hdul.writeto(self.temp('tmp.fits'), clobber=True, checksum=True)
+            hdul.writeto(self.temp('tmp.fits'), overwrite=True, checksum=True)
             with fits.open(self.temp('tmp.fits'), uint=True,
                            checksum=True) as hdul1:
                 for idx, (hdu_a, hdu_b) in enumerate(zip(hdul, hdul1)):
@@ -152,7 +137,7 @@ class TestChecksumFunctions(FitsTestCase):
         x = fits.hdu.groups.GroupData(imdata, parnames=[str('abc'), str('xyz')],
                                       pardata=[pdata1, pdata2], bitpix=-32)
         hdu = fits.GroupsHDU(x)
-        hdu.writeto(self.temp('tmp.fits'), clobber=True, checksum=True)
+        hdu.writeto(self.temp('tmp.fits'), overwrite=True, checksum=True)
         with fits.open(self.temp('tmp.fits'), checksum=True) as hdul:
             assert comparerecords(hdul[0].data, hdu.data)
             assert 'CHECKSUM' in hdul[0].header
@@ -167,7 +152,7 @@ class TestChecksumFunctions(FitsTestCase):
         col2 = fits.Column(name='V_mag', format='E', array=a2)
         cols = fits.ColDefs([col1, col2])
         tbhdu = fits.BinTableHDU.from_columns(cols)
-        tbhdu.writeto(self.temp('tmp.fits'), clobber=True, checksum=True)
+        tbhdu.writeto(self.temp('tmp.fits'), overwrite=True, checksum=True)
         with fits.open(self.temp('tmp.fits'), checksum=True) as hdul:
             assert comparerecords(tbhdu.data, hdul[1].data)
             assert 'CHECKSUM' in hdul[0].header
@@ -185,7 +170,7 @@ class TestChecksumFunctions(FitsTestCase):
                          'O'))
         c2 = fits.Column(name='xyz', format='2I', array=[[11, 3], [12, 4]])
         tbhdu = fits.BinTableHDU.from_columns([c1, c2])
-        tbhdu.writeto(self.temp('tmp.fits'), clobber=True, checksum=True)
+        tbhdu.writeto(self.temp('tmp.fits'), overwrite=True, checksum=True)
         with fits.open(self.temp('tmp.fits'), checksum=True) as hdul:
             assert comparerecords(tbhdu.data, hdul[1].data)
             assert 'CHECKSUM' in hdul[0].header
@@ -208,7 +193,7 @@ class TestChecksumFunctions(FitsTestCase):
         c3 = fits.Column(name='t1', format='I', array=[91, 92, 93])
         x = fits.ColDefs([c1, c2, c3])
         hdu = fits.TableHDU.from_columns(x)
-        hdu.writeto(self.temp('tmp.fits'), clobber=True, checksum=True)
+        hdu.writeto(self.temp('tmp.fits'), overwrite=True, checksum=True)
         with fits.open(self.temp('tmp.fits'), checksum=True) as hdul:
             assert comparerecords(hdu.data, hdul[1].data)
             assert 'CHECKSUM' in hdul[0].header
@@ -220,13 +205,13 @@ class TestChecksumFunctions(FitsTestCase):
                 # The checksum ends up being different on Windows, possibly due
                 # to slight floating point differences
                 assert 'CHECKSUM' in hdul[1].header
-                assert hdul[1].header['CHECKSUM'] == '51IDA1G981GCA1G9'
+                assert hdul[1].header['CHECKSUM'] == '3rKFAoI94oICAoI9'
                 assert 'DATASUM' in hdul[1].header
-                assert hdul[1].header['DATASUM'] == '1948208413'
+                assert hdul[1].header['DATASUM'] == '1914653725'
 
     def test_compressed_image_data(self):
         with fits.open(self.data('comp.fits')) as h1:
-            h1.writeto(self.temp('tmp.fits'), clobber=True, checksum=True)
+            h1.writeto(self.temp('tmp.fits'), overwrite=True, checksum=True)
             with fits.open(self.temp('tmp.fits'), checksum=True) as h2:
                 assert np.all(h1[1].data == h2[1].data)
                 assert 'CHECKSUM' in h2[0].header
@@ -311,7 +296,7 @@ class TestChecksumFunctions(FitsTestCase):
 
     def test_append(self):
         hdul = fits.open(self.data('tb.fits'))
-        hdul.writeto(self.temp('tmp.fits'), clobber=True)
+        hdul.writeto(self.temp('tmp.fits'), overwrite=True)
         n = np.arange(100)
         fits.append(self.temp('tmp.fits'), n, checksum=True)
         hdul.close()
@@ -321,7 +306,7 @@ class TestChecksumFunctions(FitsTestCase):
 
     def test_writeto_convenience(self):
         n = np.arange(100)
-        fits.writeto(self.temp('tmp.fits'), n, clobber=True, checksum=True)
+        fits.writeto(self.temp('tmp.fits'), n, overwrite=True, checksum=True)
         hdul = fits.open(self.temp('tmp.fits'), checksum=True)
         self._check_checksums(hdul[0])
         hdul.close()
@@ -359,7 +344,7 @@ class TestChecksumFunctions(FitsTestCase):
     def test_datasum_only(self):
         n = np.arange(100, dtype='int16')
         hdu = fits.ImageHDU(n)
-        hdu.writeto(self.temp('tmp.fits'), clobber=True, checksum='datasum')
+        hdu.writeto(self.temp('tmp.fits'), overwrite=True, checksum='datasum')
         with fits.open(self.temp('tmp.fits'), checksum=True) as hdul:
             if not (hasattr(hdul[0], '_datasum') and hdul[0]._datasum):
                 pytest.fail(msg='Missing DATASUM keyword')
@@ -367,14 +352,6 @@ class TestChecksumFunctions(FitsTestCase):
             if not (hasattr(hdul[0], '_checksum') and not hdul[0]._checksum):
                 pytest.fail(msg='Non-empty CHECKSUM keyword')
 
-            if not (hasattr(hdul[0], '_datasum_comment') and
-                    hdul[0]._datasum_comment):
-                pytest.fail(msg='Missing DATASUM Card comment')
-
-            if not (hasattr(hdul[0], '_checksum_comment') and
-                    not hdul[0]._checksum_comment):
-                pytest.fail(msg='Non-empty CHECKSUM Card comment')
-
     def test_open_update_mode_preserve_checksum(self):
         """
         Regression test for https://aeon.stsci.edu/ssb/trac/pyfits/ticket/148 where
@@ -439,15 +416,42 @@ class TestChecksumFunctions(FitsTestCase):
             assert (data2['TIME'][1:] == data['TIME'][1:]).all()
             assert data2['TIME'][0] == 42
 
+    def test_overwrite_invalid(self):
+        """
+        Tests that invalid checksum or datasum are overwriten when the file is
+        saved.
+        """
+
+        reffile = self.temp('ref.fits')
+        with fits.open(self.data('tb.fits')) as hdul:
+            hdul.writeto(reffile, checksum=True)
+
+        testfile = self.temp('test.fits')
+        with fits.open(self.data('tb.fits')) as hdul:
+            hdul[0].header['DATASUM'] = '1       '
+            hdul[0].header['CHECKSUM'] = '8UgqATfo7TfoATfo'
+            hdul[1].header['DATASUM'] = '2349680925'
+            hdul[1].header['CHECKSUM'] = '11daD8bX98baA8bU'
+            hdul.writeto(testfile)
+
+        with fits.open(testfile) as hdul:
+            hdul.writeto(self.temp('test2.fits'), checksum=True)
+
+        with fits.open(self.temp('test2.fits')) as hdul:
+            with fits.open(reffile) as ref:
+                assert 'CHECKSUM' in hdul[0].header
+                # These checksums were verified against CFITSIO
+                assert hdul[0].header['CHECKSUM'] == ref[0].header['CHECKSUM']
+                assert 'DATASUM' in hdul[0].header
+                assert hdul[0].header['DATASUM'] == '0'
+                assert 'CHECKSUM' in hdul[1].header
+                assert hdul[1].header['CHECKSUM'] == ref[1].header['CHECKSUM']
+                assert 'DATASUM' in hdul[1].header
+                assert hdul[1].header['DATASUM'] == ref[1].header['DATASUM']
+
     def _check_checksums(self, hdu):
         if not (hasattr(hdu, '_datasum') and hdu._datasum):
             pytest.fail(msg='Missing DATASUM keyword')
 
         if not (hasattr(hdu, '_checksum') and hdu._checksum):
             pytest.fail(msg='Missing CHECKSUM keyword')
-
-        if not (hasattr(hdu, '_datasum_comment') and hdu._datasum_comment):
-            pytest.fail(msg='Missing DATASUM Card comment')
-
-        if not (hasattr(hdu, '_checksum_comment') and hdu._checksum_comment):
-            pytest.fail(msg='Missing CHECKSUM Card comment')
