@@ -107,6 +107,17 @@ def test_names_over_ids():
         'Emag', '24mag', 'f_Name']
 
 
+def test_explicit_ids():
+    with get_pkg_data_fileobj('data/names.xml', encoding='binary') as fd:
+        votable = parse(fd)
+
+    table = votable.get_first_table().to_table(use_names_over_ids=False)
+
+    assert table.colnames == [
+        'col1', 'col2', 'col3', 'col4', 'col5', 'col6', 'col7', 'col8', 'col9',
+        'col10', 'col11', 'col12', 'col13', 'col14', 'col15', 'col16', 'col17']
+
+
 def test_table_read_with_unnamed_tables():
     """
     Issue #927
