@@ -99,7 +99,7 @@ int ffgcls( fitsfile *fptr,   /* I - FITS file pointer                       */
 
     if (colnum < 1 || colnum > (fptr->Fptr)->tfield)
     {
-        sprintf(message, "Specified column number is out of range: %d",
+        snprintf(message, FLEN_ERRMSG,"Specified column number is out of range: %d",
                 colnum);
         ffpmsg(message);
         return(*status = BAD_COL_NUM);
@@ -188,7 +188,7 @@ int ffgcls( fitsfile *fptr,   /* I - FITS file pointer                       */
                 nularray[ii] = 1;
            }
            else
-             sprintf(tmpstr, cform, earray[jj]);
+             snprintf(tmpstr, 400,cform, earray[jj]);
 
            strncat(array[ii], tmpstr, dwidth);
            strcat(array[ii], ",");
@@ -202,7 +202,7 @@ int ffgcls( fitsfile *fptr,   /* I - FITS file pointer                       */
                 nularray[ii] = 1;
            }
            else
-             sprintf(tmpstr, cform, earray[jj]);
+             snprintf(tmpstr, 400,cform, earray[jj]);
 
            strncat(array[ii], tmpstr, dwidth);
            strcat(array[ii], ")");
@@ -255,7 +255,7 @@ int ffgcls( fitsfile *fptr,   /* I - FITS file pointer                       */
                 nularray[ii] = 1;
            }
            else
-             sprintf(tmpstr, cform, darray[jj]);
+             snprintf(tmpstr, 400,cform, darray[jj]);
 
            strncat(array[ii], tmpstr, dwidth);
            strcat(array[ii], ",");
@@ -269,7 +269,7 @@ int ffgcls( fitsfile *fptr,   /* I - FITS file pointer                       */
                 nularray[ii] = 1;
            }
            else
-             sprintf(tmpstr, cform, darray[jj]);
+             snprintf(tmpstr, 400,cform, darray[jj]);
 
            strncat(array[ii], tmpstr, dwidth);
            strcat(array[ii], ")");
@@ -321,11 +321,11 @@ int ffgcls( fitsfile *fptr,   /* I - FITS file pointer                       */
 
 #if defined(_MSC_VER)
     /* Microsoft Visual C++ 6.0 uses '%I64d' syntax  for 8-byte integers */
-        sprintf(tmpstr, "%20I64d", llarray[ii]);
+        snprintf(tmpstr, 400,"%20I64d", llarray[ii]);
 #elif (USE_LL_SUFFIX == 1)
-        sprintf(tmpstr, "%20lld", llarray[ii]);
+        snprintf(tmpstr, 400,"%20lld", llarray[ii]);
 #else
-        sprintf(tmpstr, "%20ld", llarray[ii]);
+        snprintf(tmpstr, 400,"%20ld", llarray[ii]);
 #endif
               *array[ii] = '\0';
               strncat(array[ii], tmpstr, 20);
@@ -466,9 +466,9 @@ int ffgcls( fitsfile *fptr,   /* I - FITS file pointer                       */
            else
            {	   
               if (intcol) {
-                sprintf(tmpstr, cform, (int) darray[ii]);
+                snprintf(tmpstr, 400,cform, (int) darray[ii]);
               } else {
-                sprintf(tmpstr, cform, darray[ii]);
+                snprintf(tmpstr, 400,cform, darray[ii]);
               }
 	      
               /* fill field with '*' if number is too wide */
@@ -509,7 +509,7 @@ int ffgcdw( fitsfile *fptr,   /* I - FITS file pointer                       */
 
     if (colnum < 1 || colnum > (fptr->Fptr)->tfield)
     {
-        sprintf(message, "Specified column number is out of range: %d",
+        snprintf(message, FLEN_ERRMSG,"Specified column number is out of range: %d",
                 colnum);
         ffpmsg(message);
         return(*status = BAD_COL_NUM);
@@ -621,13 +621,28 @@ int ffgcdw( fitsfile *fptr,   /* I - FITS file pointer                       */
                      *width = 1;
                   else if (tcode == TSTRING)   /* 'A' */
                   {
-                     cptr = dispfmt;
-                     while(!isdigit((int) *cptr) && *cptr != '\0') 
-                         cptr++;
+		    int typecode;
+		    long int repeat = 0, rwidth = 0;
+		    int gstatus = 0;
 
-                     *width = atoi(cptr);
+		    /* Deal with possible vector string with repeat / width  by parsing
+		       the TFORM=rAw keyword */
+		    if (ffgtcl(fptr, colnum, &typecode, &repeat, &rwidth, &gstatus) == 0 &&
+			rwidth >= 1 && rwidth < repeat) {
+		      *width = rwidth;
 
-                     if (*width < 1)
+		    } else {
+		      
+		      /* Hmmm, we couldn't parse the TFORM keyword by standard, so just do
+			 simple parsing */
+		      cptr = dispfmt;
+		      while(!isdigit((int) *cptr) && *cptr != '\0') 
+			cptr++;
+		      
+		      *width = atoi(cptr);
+		    }
+
+                    if (*width < 1)
                          *width = 1;  /* default is at least 1 column */
                   }
             }
@@ -685,7 +700,7 @@ int ffgcls2 ( fitsfile *fptr,   /* I - FITS file pointer                       *
     /*---------------------------------------------------*/
     if (colnum < 1 || colnum > (fptr->Fptr)->tfield)
     {
-        sprintf(message, "Specified column number is out of range: %d",
+        snprintf(message, FLEN_ERRMSG,"Specified column number is out of range: %d",
                 colnum);
         ffpmsg(message);
         return(*status = BAD_COL_NUM);
@@ -823,7 +838,7 @@ int ffgcls2 ( fitsfile *fptr,   /* I - FITS file pointer                       *
       if (*status > 0)  /* test for error during previous read operation */
       {
          dtemp = (double) next;
-         sprintf(message,
+         snprintf(message,FLEN_ERRMSG,
           "Error reading elements %.0f thru %.0f of data array (ffpcls).",
              dtemp+1., dtemp+ntodo);
 
